summaryrefslogtreecommitdiffstats
path: root/src/k3bservicemenuinstaller.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/k3bservicemenuinstaller.h')
-rw-r--r--src/k3bservicemenuinstaller.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/k3bservicemenuinstaller.h b/src/k3bservicemenuinstaller.h
index 271d314..015a672 100644
--- a/src/k3bservicemenuinstaller.h
+++ b/src/k3bservicemenuinstaller.h
@@ -38,14 +38,14 @@ class K3bServiceInstaller
bool allInstalled() const;
/**
* If tqparent != 0 a messagebox will be shown in case of an error.
*/
- bool install( TQWidget* tqparent = 0 );
+ bool install( TQWidget* parent = 0 );
/**
* If tqparent != 0 a messagebox will be shown in case of an error.
*/
- bool remove( TQWidget* tqparent = 0 );
+ bool remove( TQWidget* parent = 0 );
private:
class Private;
@@ -38,14 +38,14 @@ class K3bServiceInstaller
bool allInstalled() const;
/**
- * If tqparent != 0 a messagebox will be shown in case of an error.
+ * If parent != 0 a messagebox will be shown in case of an error.
*/
@@ -38,14 +38,14 @@ class K3bServiceInstaller
/**
- * If tqparent != 0 a messagebox will be shown in case of an error.
+ * If parent != 0 a messagebox will be shown in case of an error.
*/